# NHDSPy
[![Documentation Status](https://readthedocs.org/projects/nhdspy/badge/?version=latest)](https://nhdspy.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/dstansby/nhdspy.svg?branch=master)](https://travis-ci.org/dstansby/nhdspy)
[![codecov](https://codecov.io/gh/dstansby/NHDSPy/branch/master/graph/badge.svg)](https://codecov.io/gh/dstansby/NHDSPy)

Python wrapper for the NHDS dispersion relation solver. For the original NHDS code see https://github.com/danielver02/NHDS.

If you use this software to produce data for publication, please cite the NHDS paper: http://iopscience.iop.org/article/10.3847/2515-5172/aabfe3
